class ColorFiddle extends Backbone.View
  
  events:
    "slide #slider-hue": "slideHue"
    "slide #slider-sat": "slideSat"
    "slide #slider-lum": "slideLum"
    "click #css": "selectCss"
    "click #less": "selectLess"


  initialize: ->
    
    @sliderHue = @$("#slider-hue")
    @sliderSat = @$("#slider-sat")
    @sliderLum = @$("#slider-lum")
    
    @cssSelectLink = @$("#css")
    @lessSelectLink = @$("#less")
    
    @cssSelectBox = @$("#preprocessor-css")
    @lessSelectBox = @$("#preprocessor-less")
    
    @hueMod = @$("#hueMod")
    @satMod = @$("#satMod")
    @lumMod = @$("#lumMod")
    
    @result = @$("#result")
    
    @leCss  = @$("#leCss")
    @leHtml = @$("#leHtml")

    @leCssEditor = CodeMirror.fromTextArea @leCss[0], onChange: => @populateIframe()
    @leHtmlEditor = CodeMirror.fromTextArea @leHtml[0], mode: "text/html", onChange: => @populateIframe()
    
    @sliderHue.slider min: -180, max: 180, value: @hueMod.val()
    @sliderSat.slider min: -100, max: 100, value: @satMod.val()
    @sliderLum.slider min: -100, max: 100, value: @lumMod.val()
    
    $("#" + $(".radio input[type=radio]:checked").attr("value")).addClass("active")

    @populateIframe()

  selectCss: (e) ->
    @cssSelectBox.attr("checked","checked")
    @cssSelectLink.addClass("active")
    @lessSelectLink.removeClass("active")
    
  selectLess: (e) ->
    @lessSelectBox.attr("checked","checked")
    @lessSelectLink.addClass("active")
    @cssSelectLink.removeClass("active")

  slideHue: (e, ui) ->
    @hueMod.val(ui.value)
    @populateIframe()
  
  
  slideSat: (e, ui) ->
    @satMod.val(ui.value)
    @populateIframe()
  
  
  slideLum: (e, ui) ->
    @lumMod.val(ui.value);
    @populateIframe()
  
  
  populateIframe: ->
    cssStr = @leCssEditor.getValue()
    htmlStr = @leHtmlEditor.getValue()

    regex = /(#[A-Fa-f0-9]{6}|#[A-Fa-f0-9]{3})|(rgb\(\d+,\s\d+,\s\d+\))|(rgba\(\d+,\s\d+,\s\d+,\s\d+\.\d+\))/g
    modColor = (cssStr, p1, p2, p3) => @modifyColor(p1,p2,p3)

    cssStr = cssStr.replace(regex, modColor)

    @replaceIframeContent "<div>#{htmlStr}</div>"
    if $('input:radio[name=style]:checked').val() == 'less'
      new(less.Parser)().parse cssStr, (e, tree) =>
        cssStr = tree.toCSS()
        @appendIframeContent "<style type='text/css'>#{cssStr}</style>"
    else
      @appendIframeContent "<style type='text/css'>#{cssStr}</style>"
  
  replaceIframeContent: (src) ->
    doc = @result[0].contentDocument
    doc.body.innerHTML = src
    
  appendIframeContent: (src) ->
    doc = @result[0].contentDocument
    doc.body.innerHTML += src
  
  modifyColor: (c1,c2,c3) ->
    hexRgbRegex = /(#[A-Fa-f0-9]{6}|#[A-Fa-f0-9]{3})|(rgb\(\d+,\s\d+,\s\d+\))/
    rgbaRegex = /(rgba\(\d+,\s\d+,\s\d+,\s\d+\.\d+\))/
    outputFormat = "hex"
        
    if c1 != ""
      color = c1
    else if c2 != ""
      color = c2
    else if c3 != ""
      color = c3
      outputFormat = "RGBA"
    
    originalColor = $.colors(color);
    hsl = originalColor.model('HSL').get();
    
    hsl[0] = @modifyHue(hsl[0]);
    hsl[1] = @modifySat(hsl[1]);
    hsl[2] = @modifyLum(hsl[2]);
    
    newColor = originalColor.toString(outputFormat);
    return newColor;


  modifyHue: (hue) ->
    hueMod = parseInt(@hueMod.val());
    newHue = hueMod + hue;
    if newHue < 0
      newHue = 360 + newHue
    else if newHue > 360
      newHue = newHue % 360
    return newHue


  modifySat: (sat) ->
    sat += parseInt @satMod.val()
    if sat < 0
      sat = 0
    else if sat > 100
      sat = 100
    return sat
  
  
  modifyLum: (lum) ->
    lum += parseInt @lumMod.val()
    if lum < 0
      lum = 0
    else if lum > 100
      lum = 100
    return lum



$ ->
  new ColorFiddle(el: $('#colorfiddle'))
  layout = $("#colorfiddle").layout
    north__resizable: false,
    north__resizable: false,
    north__closable: false,
    north__spacing_open: 0,
    north__size: 50,
    west__size: "50%",
    west__minSize: 550,
    useStateCookie: true,
    enableCursorHotkey: false

