var ColorFiddle;
var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
  for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
  function ctor() { this.constructor = child; }
  ctor.prototype = parent.prototype;
  child.prototype = new ctor;
  child.__super__ = parent.prototype;
  return child;
}, __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };
ColorFiddle = (function() {
  __extends(ColorFiddle, Backbone.View);
  function ColorFiddle() {
    ColorFiddle.__super__.constructor.apply(this, arguments);
  }
  ColorFiddle.prototype.events = {
    "slide #slider-hue": "slideHue",
    "slide #slider-sat": "slideSat",
    "slide #slider-lum": "slideLum",
    "click #css": "selectCss",
    "click #less": "selectLess"
  };
  ColorFiddle.prototype.initialize = function() {
    this.sliderHue = this.$("#slider-hue");
    this.sliderSat = this.$("#slider-sat");
    this.sliderLum = this.$("#slider-lum");
    this.cssSelectLink = this.$("#css");
    this.lessSelectLink = this.$("#less");
    this.cssSelectBox = this.$("#preprocessor-css");
    this.lessSelectBox = this.$("#preprocessor-less");
    this.hueMod = this.$("#hueMod");
    this.satMod = this.$("#satMod");
    this.lumMod = this.$("#lumMod");
    this.result = this.$("#result");
    this.leCss = this.$("#leCss");
    this.leHtml = this.$("#leHtml");
    this.leCssEditor = CodeMirror.fromTextArea(this.leCss[0], {
      onChange: __bind(function() {
        return this.populateIframe();
      }, this)
    });
    this.leHtmlEditor = CodeMirror.fromTextArea(this.leHtml[0], {
      mode: "text/html",
      onChange: __bind(function() {
        return this.populateIframe();
      }, this)
    });
    this.sliderHue.slider({
      min: -180,
      max: 180,
      value: this.hueMod.val()
    });
    this.sliderSat.slider({
      min: -100,
      max: 100,
      value: this.satMod.val()
    });
    this.sliderLum.slider({
      min: -100,
      max: 100,
      value: this.lumMod.val()
    });
    $("#" + $(".radio input[type=radio]:checked").attr("value")).addClass("active");
    return this.populateIframe();
  };
  ColorFiddle.prototype.selectCss = function(e) {
    this.cssSelectBox.attr("checked", "checked");
    this.cssSelectLink.addClass("active");
    return this.lessSelectLink.removeClass("active");
  };
  ColorFiddle.prototype.selectLess = function(e) {
    this.lessSelectBox.attr("checked", "checked");
    this.lessSelectLink.addClass("active");
    return this.cssSelectLink.removeClass("active");
  };
  ColorFiddle.prototype.slideHue = function(e, ui) {
    this.hueMod.val(ui.value);
    return this.populateIframe();
  };
  ColorFiddle.prototype.slideSat = function(e, ui) {
    this.satMod.val(ui.value);
    return this.populateIframe();
  };
  ColorFiddle.prototype.slideLum = function(e, ui) {
    this.lumMod.val(ui.value);
    return this.populateIframe();
  };
  ColorFiddle.prototype.populateIframe = function() {
    var cssStr, htmlStr, modColor, regex;
    cssStr = this.leCssEditor.getValue();
    htmlStr = this.leHtmlEditor.getValue();
    regex = /(#[A-Fa-f0-9]{6}|#[A-Fa-f0-9]{3})|(rgb\(\d+,\s\d+,\s\d+\))|(rgba\(\d+,\s\d+,\s\d+,\s\d+\.\d+\))/g;
    modColor = __bind(function(cssStr, p1, p2, p3) {
      return this.modifyColor(p1, p2, p3);
    }, this);
    cssStr = cssStr.replace(regex, modColor);
    this.replaceIframeContent("<div>" + htmlStr + "</div>");
    if ($('input:radio[name=style]:checked').val() === 'less') {
      return new less.Parser().parse(cssStr, __bind(function(e, tree) {
        cssStr = tree.toCSS();
        return this.appendIframeContent("<style type='text/css'>" + cssStr + "</style>");
      }, this));
    } else {
      return this.appendIframeContent("<style type='text/css'>" + cssStr + "</style>");
    }
  };
  ColorFiddle.prototype.replaceIframeContent = function(src) {
    var doc;
    doc = this.result[0].contentDocument;
    return doc.body.innerHTML = src;
  };
  ColorFiddle.prototype.appendIframeContent = function(src) {
    var doc;
    doc = this.result[0].contentDocument;
    return doc.body.innerHTML += src;
  };
  ColorFiddle.prototype.modifyColor = function(c1, c2, c3) {
    var color, hexRgbRegex, hsl, newColor, originalColor, outputFormat, rgbaRegex;
    hexRgbRegex = /(#[A-Fa-f0-9]{6}|#[A-Fa-f0-9]{3})|(rgb\(\d+,\s\d+,\s\d+\))/;
    rgbaRegex = /(rgba\(\d+,\s\d+,\s\d+,\s\d+\.\d+\))/;
    outputFormat = "hex";
    if (c1 !== "") {
      color = c1;
    } else if (c2 !== "") {
      color = c2;
    } else if (c3 !== "") {
      color = c3;
      outputFormat = "RGBA";
    }
    originalColor = $.colors(color);
    hsl = originalColor.model('HSL').get();
    hsl[0] = this.modifyHue(hsl[0]);
    hsl[1] = this.modifySat(hsl[1]);
    hsl[2] = this.modifyLum(hsl[2]);
    newColor = originalColor.toString(outputFormat);
    return newColor;
  };
  ColorFiddle.prototype.modifyHue = function(hue) {
    var hueMod, newHue;
    hueMod = parseInt(this.hueMod.val());
    newHue = hueMod + hue;
    if (newHue < 0) {
      newHue = 360 + newHue;
    } else if (newHue > 360) {
      newHue = newHue % 360;
    }
    return newHue;
  };
  ColorFiddle.prototype.modifySat = function(sat) {
    sat += parseInt(this.satMod.val());
    if (sat < 0) {
      sat = 0;
    } else if (sat > 100) {
      sat = 100;
    }
    return sat;
  };
  ColorFiddle.prototype.modifyLum = function(lum) {
    lum += parseInt(this.lumMod.val());
    if (lum < 0) {
      lum = 0;
    } else if (lum > 100) {
      lum = 100;
    }
    return lum;
  };
  return ColorFiddle;
})();
$(function() {
  var layout;
  new ColorFiddle({
    el: $('#colorfiddle')
  });
  return layout = $("#colorfiddle").layout({
    north__resizable: false,
    north__resizable: false,
    north__closable: false,
    north__spacing_open: 0,
    north__size: 50,
    west__size: "50%",
    west__minSize: 550,
    useStateCookie: true,
    enableCursorHotkey: false
  });
});